@@ -18,6 +18,13 @@ biocBuildReportDB <- function(
     if (version %in% c("release", "devel"))
         version <- BiocManager:::.version_bioc(version)
 
+    version <- try(as.package_version(version), silent = TRUE)
+
+    if (is(version, "try-error"))
+        stop(
+            "'version' is not 'release', 'devel', or a valid 'package_version'"
+        )
+
     pkgType <- match.arg(pkgType, several.ok = TRUE)
     pkgType <- .matchGetShortName(pkgType, "stat.url")
 
