@@ -23,23 +23,29 @@
 #' )
 #' }
 #' @export
-biocPkgRanges <-
-    function(start, end, condition = c("ERROR", "WARNINGS"),
-        phase = "buildsrc", version = c("devel", "release"))
-{
+biocPkgRanges <- function(
+    start,
+    end,
+    condition = c("ERROR", "WARNINGS"),
+    phase = "buildsrc",
+    version = c("devel", "release")
+) {
     condition <- match.arg(condition)
     version <- match.arg(version)
 
     sdat <- biocBuildStatusDB(version = version, pkgType = "software")
 
-    cur <- which(sdat$package >= start & sdat$package <= end)
+    cur <- which(sdat[["pkg"]] >= start & sdat[["pkg"]] <= end)
     if (!length(cur))
         stop("no packages in range")
-    mine <- sdat[cur,]
-    crit <- mine[grep("OK|skipped", mine$status, invert = TRUE), ]
+
+    mine <- sdat[cur, ]
+
+    crit <- mine[grep("OK|skipped", mine[["result"]], invert = TRUE), ]
     if (!nrow(crit))
         stop("all packages OK or skipped!")
-    flag <- crit[grep(condition, crit$status),]
-    flagged <- flag[grep(phase, flag$status),]
-    split(flagged, flagged$package)
+
+    flag <- crit[grep(condition, crit[["result"]]), ]
+    flagged <- flag[grep(phase, flag[["stage"]]), ]
+    split(flagged, flagged[["pkg"]])
 }
